aboutsummaryrefslogtreecommitdiff
path: root/nuttx/fs/fs_seekdir.c
diff options
context:
space:
mode:
authorLorenz Meier <lm@inf.ethz.ch>2012-08-11 21:19:27 +0200
committerLorenz Meier <lm@inf.ethz.ch>2012-08-11 21:19:27 +0200
commit22c1a03af79d84e4c340c4a8f64b7c646f9f2d5a (patch)
treee01f26e6d8c9fee37666bd648d60f722aecc6f32 /nuttx/fs/fs_seekdir.c
parent18c6c620c048abba7cbd2530f80ea6d0207704b1 (diff)
parent24688ae7f9522cb44924980ea2364c5a1029fd61 (diff)
downloadpx4-firmware-22c1a03af79d84e4c340c4a8f64b7c646f9f2d5a.tar.gz
px4-firmware-22c1a03af79d84e4c340c4a8f64b7c646f9f2d5a.tar.bz2
px4-firmware-22c1a03af79d84e4c340c4a8f64b7c646f9f2d5a.zip
Merge branch 'master' of github.com:PX4/Firmware
Diffstat (limited to 'nuttx/fs/fs_seekdir.c')
-rw-r--r--nuttx/fs/fs_seekdir.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/nuttx/fs/fs_seekdir.c b/nuttx/fs/fs_seekdir.c
index ec530c67d..781d35f27 100644
--- a/nuttx/fs/fs_seekdir.c
+++ b/nuttx/fs/fs_seekdir.c
@@ -53,10 +53,10 @@
****************************************************************************/
/****************************************************************************
- * Name: seekpsuedodir
+ * Name: seekpseudodir
****************************************************************************/
-static inline void seekpsuedodir(struct fs_dirent_s *idir, off_t offset)
+static inline void seekpseudodir(struct fs_dirent_s *idir, off_t offset)
{
struct inode *curr;
struct inode *prev;
@@ -76,7 +76,7 @@ static inline void seekpsuedodir(struct fs_dirent_s *idir, off_t offset)
else
{
pos = idir->fd_position;
- curr = idir->u.psuedo.fd_next;
+ curr = idir->u.pseudo.fd_next;
}
/* Traverse the peer list starting at the 'root' of the
@@ -90,8 +90,8 @@ static inline void seekpsuedodir(struct fs_dirent_s *idir, off_t offset)
/* Now get the inode to vist next time that readdir() is called */
- prev = idir->u.psuedo.fd_next;
- idir->u.psuedo.fd_next = curr; /* The next node to visit (might be null) */
+ prev = idir->u.pseudo.fd_next;
+ idir->u.pseudo.fd_next = curr; /* The next node to visit (might be null) */
idir->fd_position = pos; /* Might be beyond the last dirent */
if (curr)
@@ -223,8 +223,8 @@ void seekdir(FAR DIR *dirp, off_t offset)
else
#endif
{
- /* The node is part of the root psuedo file system */
+ /* The node is part of the root pseudo file system */
- seekpsuedodir(idir, offset);
+ seekpseudodir(idir, offset);
}
}